# -*- coding: utf-8 -*-

"""OPTIMISATION PROBLEM MODULES.

This module contains submodules for solving optimisation problems.

:Author: Samuel Farrens <samuel.farrens@cea.fr>

"""

__all__ = ['cost', 'gradient', 'linear', 'algorithms', 'proximity', 'reweight']
